==> netgen_mesher-6.2.2404.post95.dev1-cp313-cp313-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: netgen_mesher-6.2.2404.post95.dev1.data/data/lib/cmake/netgen/NetgenConfig.cmake <==
set(NETGEN_VERSION "6.2.2404-95-ge51918df")
set(NETGEN_VERSION_MAJOR "6")
set(NETGEN_VERSION_MINOR "2")
set(NETGEN_VERSION_PATCH "2404")
set(NETGEN_VERSION_TWEAK "95")

get_filename_component(NETGEN_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

get_filename_component(NETGEN_DIR "${NETGEN_CMAKE_DIR}/../../../" ABSOLUTE)

set(NETGEN_COMPILE_DEFINITIONS "HAVE_DLFCN_H;$<$<CONFIG:Release>:OCC_CONVERT_SIGNALS>;OCCGEOMETRY")

get_filename_component(NETGEN_INCLUDE_DIR "${NETGEN_CMAKE_DIR}/../../../include/netgen" ABSOLUTE)
get_filename_component(NETGEN_BINARY_DIR "${NETGEN_CMAKE_DIR}/../../../bin" ABSOLUTE)
get_filename_component(NETGEN_LIBRARY_DIR "${NETGEN_CMAKE_DIR}/../../python3.13/site-packages/netgen_mesher.libs" ABSOLUTE)
get_filename_component(NETGEN_PYTHON_DIR "${NETGEN_CMAKE_DIR}/../../python3.13/site-packages" ABSOLUTE)
get_filename_component(NETGEN_RESOURCE_DIR "${NETGEN_CMAKE_DIR}/../../../share" ABSOLUTE)

set(NETGEN_SOURCE_DIR "/builds/ngsolve/netgen")

set(NETGEN_BUILD_FOR_CONDA "ON")
set(NETGEN_CHECK_RANGE "OFF")
set(NETGEN_INCLUDE_DIRS "${NETGEN_INCLUDE_DIR}/include;${NETGEN_INCLUDE_DIR}")
set(NETGEN_CMAKE_THREAD_LIBS_INIT "-lpthread")
set(NETGEN_FFMPEG_LIBRARIES "")
set(NETGEN_JPEG_INCLUDE_DIR "")
set(NETGEN_JPEG_LIBRARIES "")
set(NETGEN_LIBTOGL "")
set(NETGEN_METIS_INCLUDE_DIR "/builds/ngsolve/netgen/_skbuild/linux-x86_64-3.13/cmake-build/dependencies/metis/include")
set(NETGEN_METIS_LIBRARY "/builds/ngsolve/netgen/_skbuild/linux-x86_64-3.13/cmake-build/dependencies/metis/lib/libmetis.a")
set(NETGEN_MKL_LIBRARIES "")
set(NETGEN_MPI_CXX_INCLUDE_PATH "")
set(NETGEN_MPI_CXX_LIBRARIES "")
set(NETGEN_NUMA_LIBRARY "")
set(NETGEN_OCC_DIR "")
set(NETGEN_OCC_INCLUDE_DIR "/opt/_internal/cpython-3.13.0rc2/include/opencascade")
set(NETGEN_OCC_LIBRARIES_BIN "/opt/_internal/cpython-3.13.0rc2/bin")
set(NETGEN_OCC_LIBRARIES "-Wl,--start-group;TKBO;TKBRep;TKBool;TKCAF;TKCDF;TKFillet;TKG2d;TKG3d;TKGeomAlgo;TKGeomBase;TKHLR;TKLCAF;TKMath;TKMesh;TKOffset;TKPrim;TKService;TKShHealing;TKTopAlgo;TKV3d;TKVCAF;TKXCAF;TKXSBase;TKernel;TKDEIGES;TKDESTEP;TKDESTL;-Wl,--end-group")
set(NETGEN_OCC_LIBRARY_DIR "/opt/_internal/cpython-3.13.0rc2/lib")
set(NETGEN_OPENGL_LIBRARIES "/usr/lib64/libOpenGL.so;/usr/lib64/libGLX.so;/usr/lib64/libGLU.so")
set(NETGEN_PYTHON_EXECUTABLE "/opt/_internal/cpython-3.13.0rc2/bin/python")
set(NETGEN_PYTHON_INCLUDE_DIRS "/opt/_internal/cpython-3.13.0rc2/include/python3.13")
set(NETGEN_PYTHON_LIBRARIES "Python3_LIBRARY-NOTFOUND")
set(NETGEN_TCL_INCLUDE_PATH "/usr/include")
set(NETGEN_TCL_LIBRARY "/usr/lib64/libtclstub8.6.a")
set(NETGEN_TK_DND_LIBRARY "")
set(NETGEN_TK_INCLUDE_PATH "/usr/include")
set(NETGEN_TK_LIBRARY "/usr/lib64/libtkstub8.6.a")
set(NETGEN_X11_X11_LIB "/usr/lib64/libX11.so")
set(NETGEN_X11_Xmu_LIB "/usr/lib64/libXmu.so")
set(NETGEN_ZLIB_INCLUDE_DIRS "/builds/ngsolve/netgen/_skbuild/linux-x86_64-3.13/cmake-build/dependencies/zlib/include")
set(NETGEN_ZLIB_LIBRARIES "/builds/ngsolve/netgen/_skbuild/linux-x86_64-3.13/cmake-build/dependencies/zlib/lib/libz.a")

set(NETGEN_USE_GUI ON)
set(NETGEN_USE_PYTHON ON)
set(NETGEN_USE_MPI ON)
set(NETGEN_USE_OCC ON)
set(NETGEN_USE_JPEG OFF)
set(NETGEN_USE_MPEG OFF)
set(NETGEN_USE_CGNS OFF)
set(NETGEN_INTEL_MIC OFF)
set(NETGEN_INSTALL_PROFILES OFF)
set(NETGEN_USE_CCACHE ON)
set(NETGEN_USE_NATIVE_ARCH OFF)
set(NETGEN_USE_NUMA OFF)

set(NETGEN_PYTHON_RPATH "netgen_mesher.libs")
set(NETGEN_RPATH_TOKEN "$ORIGIN")

set(NETGEN_INSTALL_DIR_PYTHON lib/python3.13/site-packages)
set(NETGEN_INSTALL_DIR_BIN bin)
set(NETGEN_INSTALL_DIR_LIB lib/python3.13/site-packages/netgen_mesher.libs)
set(NETGEN_INSTALL_DIR_INCLUDE include/netgen)
set(NETGEN_INSTALL_DIR_CMAKE lib/cmake/netgen)
set(NETGEN_INSTALL_DIR_RES share)

include(${CMAKE_CURRENT_LIST_DIR}/netgen-targets.cmake)
message(STATUS "Found Netgen: ${CMAKE_CURRENT_LIST_DIR}")

==> netgen_mesher-6.2.2405.post32.dev0-cp313-cp313-manylinux_2_17_x86_64.manylinux2014_x86_64.whl: netgen_mesher-6.2.2405.post32.dev0.data/data/lib/cmake/netgen/NetgenConfig.cmake <==
set(NETGEN_VERSION "6.2.2405-32-g141af428")
set(NETGEN_VERSION_MAJOR "6")
set(NETGEN_VERSION_MINOR "2")
set(NETGEN_VERSION_PATCH "2405")
set(NETGEN_VERSION_TWEAK "32")

get_filename_component(NETGEN_CMAKE_DIR "${CMAKE_CURRENT_LIST_FILE}" PATH)

get_filename_component(NETGEN_DIR "${NETGEN_CMAKE_DIR}/../../../" ABSOLUTE)

set(NETGEN_COMPILE_DEFINITIONS "HAVE_DLFCN_H;$<$<CONFIG:Release>:OCC_CONVERT_SIGNALS>;OCCGEOMETRY")

get_filename_component(NETGEN_INCLUDE_DIR "${NETGEN_CMAKE_DIR}/../../../include/netgen" ABSOLUTE)
get_filename_component(NETGEN_BINARY_DIR "${NETGEN_CMAKE_DIR}/../../../bin" ABSOLUTE)
get_filename_component(NETGEN_LIBRARY_DIR "${NETGEN_CMAKE_DIR}/../../python3.13/site-packages/netgen_mesher.libs" ABSOLUTE)
get_filename_component(NETGEN_PYTHON_DIR "${NETGEN_CMAKE_DIR}/../../python3.13/site-packages" ABSOLUTE)
get_filename_component(NETGEN_RESOURCE_DIR "${NETGEN_CMAKE_DIR}/../../../share" ABSOLUTE)

set(NETGEN_SOURCE_DIR "/builds/ngsolve/ngsolve/external_dependencies/netgen")

set(NETGEN_BUILD_FOR_CONDA "ON")
set(NETGEN_CHECK_RANGE "OFF")
set(NETGEN_INCLUDE_DIRS "${NETGEN_INCLUDE_DIR}/include;${NETGEN_INCLUDE_DIR}")
set(NETGEN_CMAKE_THREAD_LIBS_INIT "-lpthread")
set(NETGEN_FFMPEG_LIBRARIES "")
set(NETGEN_JPEG_INCLUDE_DIR "")
set(NETGEN_JPEG_LIBRARIES "")
set(NETGEN_LIBTOGL "")
set(NETGEN_METIS_INCLUDE_DIR "/builds/ngsolve/ngsolve/external_dependencies/netgen/_skbuild/linux-x86_64-3.13/cmake-build/dependencies/metis/include")
set(NETGEN_METIS_LIBRARY "/builds/ngsolve/ngsolve/external_dependencies/netgen/_skbuild/linux-x86_64-3.13/cmake-build/dependencies/metis/lib/libmetis.a")
set(NETGEN_MKL_LIBRARIES "")
set(NETGEN_MPI_CXX_INCLUDE_PATH "")
set(NETGEN_MPI_CXX_LIBRARIES "")
set(NETGEN_NUMA_LIBRARY "")
set(NETGEN_OCC_DIR "")
set(NETGEN_OCC_INCLUDE_DIR "/opt/_internal/cpython-3.13.0b1/include/opencascade")
set(NETGEN_OCC_LIBRARIES_BIN "/opt/_internal/cpython-3.13.0b1/bin")
set(NETGEN_OCC_LIBRARIES "-Wl,--start-group;TKBO;TKBRep;TKBool;TKCAF;TKCDF;TKFillet;TKG2d;TKG3d;TKGeomAlgo;TKGeomBase;TKHLR;TKLCAF;TKMath;TKMesh;TKOffset;TKPrim;TKService;TKShHealing;TKTopAlgo;TKV3d;TKVCAF;TKXCAF;TKXSBase;TKernel;TKDEIGES;TKDESTEP;TKDESTL;-Wl,--end-group")
set(NETGEN_OCC_LIBRARY_DIR "/opt/_internal/cpython-3.13.0b1/lib")
set(NETGEN_OPENGL_LIBRARIES "/usr/lib64/libOpenGL.so;/usr/lib64/libGLX.so;/usr/lib64/libGLU.so")
set(NETGEN_PYTHON_EXECUTABLE "/opt/_internal/cpython-3.13.0b1/bin/python")
set(NETGEN_PYTHON_INCLUDE_DIRS "/opt/_internal/cpython-3.13.0b1/include/python3.13")
set(NETGEN_PYTHON_LIBRARIES "Python3_LIBRARY-NOTFOUND")
set(NETGEN_TCL_INCLUDE_PATH "/usr/include")
set(NETGEN_TCL_LIBRARY "/usr/lib64/libtclstub8.6.a")
set(NETGEN_TK_DND_LIBRARY "")
set(NETGEN_TK_INCLUDE_PATH "/usr/include")
set(NETGEN_TK_LIBRARY "/usr/lib64/libtkstub8.6.a")
set(NETGEN_X11_X11_LIB "/usr/lib64/libX11.so")
set(NETGEN_X11_Xmu_LIB "/usr/lib64/libXmu.so")
set(NETGEN_ZLIB_INCLUDE_DIRS "/builds/ngsolve/ngsolve/external_dependencies/netgen/_skbuild/linux-x86_64-3.13/cmake-build/dependencies/zlib/include")
set(NETGEN_ZLIB_LIBRARIES "/builds/ngsolve/ngsolve/external_dependencies/netgen/_skbuild/linux-x86_64-3.13/cmake-build/dependencies/zlib/lib/libz.a")

set(NETGEN_USE_GUI ON)
set(NETGEN_USE_PYTHON ON)
set(NETGEN_USE_MPI ON)
set(NETGEN_USE_OCC ON)
set(NETGEN_USE_JPEG OFF)
set(NETGEN_USE_MPEG OFF)
set(NETGEN_USE_CGNS OFF)
set(NETGEN_INTEL_MIC OFF)
set(NETGEN_INSTALL_PROFILES OFF)
set(NETGEN_USE_CCACHE ON)
set(NETGEN_USE_NATIVE_ARCH OFF)
set(NETGEN_USE_NUMA OFF)

set(NETGEN_PYTHON_RPATH "netgen_mesher.libs")
set(NETGEN_RPATH_TOKEN "$ORIGIN")

set(NETGEN_INSTALL_DIR_PYTHON lib/python3.13/site-packages)
set(NETGEN_INSTALL_DIR_BIN bin)
set(NETGEN_INSTALL_DIR_LIB lib/python3.13/site-packages/netgen_mesher.libs)
set(NETGEN_INSTALL_DIR_INCLUDE include/netgen)
set(NETGEN_INSTALL_DIR_CMAKE lib/cmake/netgen)
set(NETGEN_INSTALL_DIR_RES share)

include(${CMAKE_CURRENT_LIST_DIR}/netgen-targets.cmake)
message(STATUS "Found Netgen: ${CMAKE_CURRENT_LIST_DIR}")
